pub struct SoundAnalysisPreprocessing {
pub sound_analysis_preprocessing_type: Option<SoundAnalysisPreprocessingType>,
}Expand description
A model which takes audio signal samples as input and outputs an array of preprocessed samples according to the specified preprocessing types
Fields
sound_analysis_preprocessing_type: Option<SoundAnalysisPreprocessingType>Vision feature print type