pub struct TextClassifier {
pub revision: u32,
pub language: String,
pub model_parameter_data: Vec<u8>,
pub class_labels: Option<ClassLabels>,
}Expand description
A model which takes a single input string and outputs a label for the input.
Fields
revision: u32Stores the resivion number for the model, revision 1 is available on iOS, tvOS 12.0+, macoOS 10.14+
language: StringStores the language of the model, as specified in BCP-47 format, e.g. “en-US”. See https://tools.ietf.org/html/bcp47
model_parameter_data: Vec<u8>Stores the byte representation of learned model parameters
class_labels: Option<ClassLabels>Stores the set of output class labels