#[repr(i32)]pub enum ScatterMode {
ScatterUpdate = 0,
ScatterAdd = 1,
ScatterSub = 2,
ScatterMul = 3,
ScatterDiv = 4,
ScatterMax = 5,
ScatterMin = 6,
}Expand description
Scatter accumulation mode.
Variants
ScatterUpdate = 0
ScatterAdd = 1
add
ScatterSub = 2
subtract
ScatterMul = 3
multiply
ScatterDiv = 4
divide
ScatterMax = 5
maximum
ScatterMin = 6
minimum
Implementations
Sourceimpl ScatterMode
impl ScatterMode
Sourceimpl ScatterMode
impl ScatterMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.