pub struct AddLayerParams {
pub alpha: f32,
}Expand description
A layer that performs elementwise addition. This layer has limited broadcasting support. For general broadcasting see AddBroadcastableLayer.
.. code::
y = AddLayer(x1,x2,...)Requires 1 or more than 1 input and produces 1 output.
Input In general, there are no rank constraints. However, only certain set of shapes are broadcastable. For example: [B, 1, 1, 1], [B, C, 1, 1], [B, 1, H, W], [B, C, H, W] Output A blob with shape equal to the input blob.
If only one input is provided, scalar addition is performed:
.. math:: y = x + \alpha
Fields
alpha: f32Scalar to be added to the input. Only used if there is a single input.