ArgMaxLayerParams

Struct ArgMaxLayerParams 

pub struct ArgMaxLayerParams {
    pub axis: i64,
    pub remove_dim: bool,
}
A layer that returns the indices of the maximum value along a specified axis in a tensor.

Requires 1 input and produces 1 output. Negative indexing is supported.

Output has the same rank as the input if “removeDim” is False (default). Output has rank one less than the input if “removeDim” is True and input rank is more than 1.

e.g.:

input shape = (45, 34, 10, 5) axis = -2 output shape = (45, 1, 10, 5), if removeDim = False (default) output shape = (45, 10, 5), if removeDim = True

input shape = (5,) axis = 0 output shape = (1,), if removeDim = False or True

Fields

axis: i64remove_dim: bool