pub struct ArgMinLayerParams {
pub axis: i64,
pub remove_dim: bool,
}Expand description
A layer that returns the indices of the minimum value along a specified axis in a tensor.
Requires 1 input and produces 1 output. Negative indexing is supported.
Output has the same rank as the input if “removeDim” is False (default). Output has rank one less than the input if “removeDim” is True and input rank is more than 1.
e.g.:
input shape = (45, 34, 10, 5) axis = -2 output shape = (45, 1, 10, 5), if removeDim = False (default) output shape = (45, 10, 5), if removeDim = True
input shape = (5,) axis = 0 output shape = (1,), if removeDim = False or True
Fields
axis: i64remove_dim: boolTrait Implementations
Sourceimpl Clone for ArgMinLayerParams
impl Clone for ArgMinLayerParams
Sourcefn clone(&self) -> ArgMinLayerParams
fn clone(&self) -> ArgMinLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgMinLayerParams
impl Debug for ArgMinLayerParams
Sourceimpl Default for ArgMinLayerParams
impl Default for ArgMinLayerParams
Sourceimpl Hash for ArgMinLayerParams
impl Hash for ArgMinLayerParams
Sourceimpl Message for ArgMinLayerParams
impl Message for ArgMinLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ArgMinLayerParams
impl PartialEq for ArgMinLayerParams
Sourcefn eq(&self, other: &ArgMinLayerParams) -> bool
fn eq(&self, other: &ArgMinLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ArgMinLayerParams
impl Eq for ArgMinLayerParams
impl StructuralPartialEq for ArgMinLayerParams