pub struct ArgSortLayerParams {
pub axis: i64,
pub descending: bool,
}Expand description
A layer that returns the indices that would sort the input tensor, along a specified axis.
Requires 1 input and produces 1 output.
Output has the same rank and shape as the input.
Value of “axis” must be positive and less than the rank of the input.
e.g.:
input shape = (5,) axis = 0 input values = [3.1, 5.4, 32.9, 3.2, 77.0] output shape = (5,) output values = [0, 3, 1, 2, 4], descending = False output values = [4, 2, 1, 3, 0], descending = True
input shape = (2,3) axis = 1 input values = [[3, 5, 32], [3, 77, 6]] output shape = (2,3) output values = [[0, 1, 2], [0, 2, 1]], descending = False output values = [[2, 1, 0], [1, 2, 0]], descending = True
Fields
axis: i64must be between [0, input_rank - 1]
descending: boolTrait Implementations
Sourceimpl Clone for ArgSortLayerParams
impl Clone for ArgSortLayerParams
Sourcefn clone(&self) -> ArgSortLayerParams
fn clone(&self) -> ArgSortLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgSortLayerParams
impl Debug for ArgSortLayerParams
Sourceimpl Default for ArgSortLayerParams
impl Default for ArgSortLayerParams
Sourceimpl Hash for ArgSortLayerParams
impl Hash for ArgSortLayerParams
Sourceimpl Message for ArgSortLayerParams
impl Message for ArgSortLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ArgSortLayerParams
impl PartialEq for ArgSortLayerParams
Sourcefn eq(&self, other: &ArgSortLayerParams) -> bool
fn eq(&self, other: &ArgSortLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ArgSortLayerParams
impl Eq for ArgSortLayerParams
impl StructuralPartialEq for ArgSortLayerParams