pub struct ArrayFeatureExtractor {
pub extract_index: Vec<u64>,
}Expand description
An array feature extractor.
Given an index, extracts the value at that index from its array input. Indexes are zero-based.
Fields
extract_index: Vec<u64>Trait Implementations
Sourceimpl Clone for ArrayFeatureExtractor
impl Clone for ArrayFeatureExtractor
Sourcefn clone(&self) -> ArrayFeatureExtractor
fn clone(&self) -> ArrayFeatureExtractor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArrayFeatureExtractor
impl Debug for ArrayFeatureExtractor
Sourceimpl Default for ArrayFeatureExtractor
impl Default for ArrayFeatureExtractor
Sourceimpl Hash for ArrayFeatureExtractor
impl Hash for ArrayFeatureExtractor
Sourceimpl Message for ArrayFeatureExtractor
impl Message for ArrayFeatureExtractor
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ArrayFeatureExtractor
impl PartialEq for ArrayFeatureExtractor
Sourcefn eq(&self, other: &ArrayFeatureExtractor) -> bool
fn eq(&self, other: &ArrayFeatureExtractor) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ArrayFeatureExtractor
impl StructuralPartialEq for ArrayFeatureExtractor