pub struct AverageLayerParams {}Expand description
A layer that computes the elementwise average of the inputs. This layer has limited broadcasting support. For general broadcasting see AddBroadcastableLayer.
.. code::
y = AverageLayer(x1,x2,...)Requires multiple inputs and produces 1 output.
Input In general, there are no rank constraints. However, only certain set of shapes are broadcastable. For example: [B, 1, 1, 1], [B, C, 1, 1], [B, 1, H, W], [B, C, H, W] Output A blob with the same shape as each input.