pub struct BayesianProbitRegressor {
pub number_of_features: u32,
pub bias: Option<Gaussian>,
pub features: Vec<FeatureWeight>,
pub regression_input_feature_name: String,
pub optimism_input_feature_name: String,
pub sampling_scale_input_feature_name: String,
pub sampling_truncation_input_feature_name: String,
pub mean_output_feature_name: String,
pub variance_output_feature_name: String,
pub pessimistic_probability_output_feature_name: String,
pub sampled_probability_output_feature_name: String,
}Fields
number_of_features: u32bias: Option<Gaussian>bias term
features: Vec<FeatureWeight>Set of features with associated weights
feature weights
regression_input_feature_name: StringSet this name to be the same as input feature of type multi-array (1D) in the model description you want to use as the regression input
optimism_input_feature_name: StringSet this name to be the same as optional input feature of type double in the model description you want to use as the optimism input
sampling_scale_input_feature_name: StringSet this name to be the same as optional input feature of type double in the model description you want to use as the samplingScale input
sampling_truncation_input_feature_name: StringSet this name to be the same as optional input feature of type double in the model description you want to use as the samplingBounds input
mean_output_feature_name: Stringname of ‘mean’ output feature
variance_output_feature_name: Stringname of ‘variance’ output feature
pessimistic_probability_output_feature_name: Stringname of ‘pessimistic’ output feature
sampled_probability_output_feature_name: Stringname of ‘sampled’ output feature: samples from the scaled posterior probability distribuiton