pub struct BoxCoordinatesMode {
pub box_mode: i32,
}Expand description
Specifies the convention used to specify four bounding box coordinates for an image of size (Height, Width). The (0,0) coordinate corresponds to the top-left corner of the image.
Fields
box_mode: i32Implementations
Sourceimpl BoxCoordinatesMode
impl BoxCoordinatesMode
Sourcepub fn box_mode(&self) -> Coordinates
pub fn box_mode(&self) -> Coordinates
Returns the enum value of box_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_box_mode(&mut self, value: Coordinates)
pub fn set_box_mode(&mut self, value: Coordinates)
Sets box_mode to the provided enum value.