Convolution3DLayerParams

Struct Convolution3DLayerParams 

pub struct Convolution3DLayerParams {
Show 24 fields pub output_channels: i32, pub input_channels: i32, pub n_groups: i32, pub kernel_depth: i32, pub kernel_height: i32, pub kernel_width: i32, pub stride_depth: i32, pub stride_height: i32, pub stride_width: i32, pub dilation_depth: i32, pub dilation_height: i32, pub dilation_width: i32, pub has_bias: bool, pub weights: Option<WeightParams>, pub bias: Option<WeightParams>, pub padding_type: i32, pub custom_padding_front: i32, pub custom_padding_back: i32, pub custom_padding_top: i32, pub custom_padding_bottom: i32, pub custom_padding_left: i32, pub custom_padding_right: i32, pub is_deconvolution: bool, pub output_shape: Vec<u64>,
}
A layer that performs a 3-dimensional convolution.

.. code::

  y = Convolution3DLayer(x)

Input A blob of rank 5. The input blob’s shape should be \[batch, channels, depth, height, width\].

Fields The bias field, if set, should have shape of \[channelsOut\].

Output A blob of rank 5. The output blob’s shape is \[batch, channelsOut, depthOut, heightOut, widthOut\].

Type of padding can be custom, valid, or same. Padded values are all zeros. Output spatial dimensions depend on the the type of padding. For details, refer to the descriptions of the PaddingType field of this Convolution3DLayerParams message.

Example For example, given an input of size \[1, 3, 3, 8, 8\], a stride of 2 in each dimension, a kernel of 3 in each dimension, 2 output channels, and same padding, this layer will compute the total padding applied in the depth, height, and width dimensions to be 2, 1, and 1, respectively. The depth padding is even and will be applied equally to both sides of the depth dimension. Since the height and width padding values are odd, they’ll be applied to the bottom/right of the height/width dimensions. Thus, the padding applied to the input will be \[1, 1, 0, 1, 0, 1\] (front, back, top, bottom, left, right). Finally, the output produced will have size \[1, 2, 2, 4, 4\].

Fields

output_channels: i32

The number of channels in the output (channelsOut). Must be a positive integer.

input_channels: i32

The number of channels in the input (channels). Must be a positive integer.

n_groups: i32

Group convolution, i.e., weight reuse along the channel axis. It must evenly divide both the number of input and output channels and be at most the number of input channels (a depthwise convolution). Input and kernels are divided into g groups and convolution is applied within the groups independently.

kernel_depth: i32

Depth of the convolution kernel. Must be a positive integer.

kernel_height: i32

Height of the convolution kernel. Must be a positive integer.

kernel_width: i32

Width of the convolution kernel. Must be a positive integer.

stride_depth: i32

Stride along the depth direction. Must be a positive integer.

stride_height: i32

Stride along the height direction. Must be a positive integer.

stride_width: i32

Stride along the width direction. Must be a positive integer.

dilation_depth: i32

Dilation along the depth direction. Must be a positive integer.

dilation_height: i32

Dilation along the height direction. Must be a positive integer.

dilation_width: i32

Dilation along the width direction. Must be a positive integer.

has_bias: bool

Flag to specify whether a bias is to be added or not. If false, then no bias is added.

weights: Option<WeightParams>

Weights associated with this layer. Weights have the shape if deconvolution == False \[outputChannels, kernelChannels, kernelDepth, kernelHeight, kernelWidth\], where kernelChannels == inputChannels / nGroups else if deconvolution == True \[outputChannels / nGroups, kernelChannels, kernelDepth, kernelHeight, kernelWidth\], where

bias: Option<WeightParams>

Must be of size \[outputChannels\].

padding_type: i32custom_padding_front: i32

Padding before the input in the depth direction. Must be zero or a positive integer. Used when the PaddingType is CustomPadding, otherwise ignored by other padding types.

custom_padding_back: i32

Padding after the input in the depth direction. Must be zero or a positive integer. Used when the PaddingType is CustomPadding, otherwise ignored by other padding types.

custom_padding_top: i32

Padding before the input in the height direction. Must be zero or a positive integer. Used when the PaddingType is CustomPadding, otherwise ignored by other padding types.

custom_padding_bottom: i32

Padding after the input in the height direction. Must be zero or a positive integer. Used when the PaddingType is CustomPadding, otherwise ignored by other padding types.

custom_padding_left: i32

Padding before the input in the width direction. Must be zero or a positive integer. Used when the PaddingType is CustomPadding, otherwise ignored by other padding types.

custom_padding_right: i32

Padding after the input in the width direction. Must be zero or a positive integer. Used when the PaddingType is CustomPadding, otherwise ignored by other padding types.

is_deconvolution: bool

Flag to specify if this is Convolution Transpose or not.

output_shape: Vec<u64>

The output shape, which has length 3 \[D_out, H_out, W_out\]. This is used only for deconvolution (isDeconvolution == true). If not set, the deconvolution output shape is calculated based on PaddingType.

Implementations

Source

impl Convolution3DLayerParams

pub fn padding_type(&self) -> PaddingType

Returns the enum value of padding_type, or the default if the field is set to an invalid enum value.

pub fn set_padding_type(&mut self, value: PaddingType)

Sets padding_type to the provided enum value.