pub struct CopyLayerParams {}Expand description
Copy Layer
A layer that copies its input tensor to the output tensor. Must have 1 input and 1 output, with distinct names. This is the only layer that is allowed to re-generate an output that is already present in the neural network prior to this layer, in which case it will overwrite the output tensor.