pub struct CustomLayerParams {
pub class_name: String,
pub weights: Vec<WeightParams>,
pub parameters: HashMap<String, CustomLayerParamValue>,
pub description: String,
}Fields
class_name: StringThe name of the class (conforming to MLCustomLayer) corresponding to this layer
weights: Vec<WeightParams>Any weights – these are serialized in binary format and memmapped at runtime
parameters: HashMap<String, CustomLayerParamValue>these may be handled as strings, so this should not be large
description: StringAn (optional) description of the layer provided by the model creator. This information is displayed when viewing the model, but does not affect the model’s execution on device.