pub struct DictVectorizer {
pub map: Option<Map>,
}Expand description
Uses an index mapping to convert a dictionary to an array.
The output array will be equal in length to the index mapping vector parameter. All keys in the input dictionary must be present in the index mapping vector.
For each item in the input dictionary, insert its value in the output array. The position of the insertion is determined by the position of the item’s key in the index mapping. Any keys not present in the input dictionary, will be zero in the output array.
For example: if the stringToIndex parameter is set to \["a", "c", "b", "z"\],
then an input of {"a": 4, "c": 8} will produce an output of \[4, 8, 0, 0\].
Fields
map: Option<Map>Trait Implementations
Sourceimpl Clone for DictVectorizer
impl Clone for DictVectorizer
Sourcefn clone(&self) -> DictVectorizer
fn clone(&self) -> DictVectorizer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DictVectorizer
impl Debug for DictVectorizer
Sourceimpl Default for DictVectorizer
impl Default for DictVectorizer
Sourceimpl Hash for DictVectorizer
impl Hash for DictVectorizer
Sourceimpl Message for DictVectorizer
impl Message for DictVectorizer
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DictVectorizer
impl PartialEq for DictVectorizer
Sourcefn eq(&self, other: &DictVectorizer) -> bool
fn eq(&self, other: &DictVectorizer) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DictVectorizer
impl StructuralPartialEq for DictVectorizer