pub struct EmbeddingLayerParams {
pub input_dim: u64,
pub output_channels: u64,
pub has_bias: bool,
pub weights: Option<WeightParams>,
pub bias: Option<WeightParams>,
}Expand description
A layer that performs a matrix lookup and optionally adds a bias. The weights matrix is stored with dimensions [outputChannels, inputDim].
.. code::
y = EmbeddingLayer(x)Requires 1 input and produces 1 output.
Input
Input values must be in the range \[0, inputDim - 1\].
Input must have rank equal to 4 or 5, such that the last 3 dimensions are all 1.
rank 4: shape (x1, 1, 1, 1). x1 is effectively the batch/sequence length.
rank 5: shape (x1, x2 , 1, 1, 1). x1 * x2 is effectively the combined batch/sequence length.Output Output rank is same as the input rank. Please see input description above. rank 4: shape (x1, outputChannels, 1, 1) rank 5: shape (x1, x2, outputChannels, 1, 1)
Fields
input_dim: u64Size of the input dictionary.
output_channels: u64Size of the output vectors.
has_bias: boolWhether a bias is added or not.
weights: Option<WeightParams>2-D weights of dimensions [outputChannels, inputDim].
bias: Option<WeightParams>Bias of size [outputChannels].