pub struct Exp2LayerParams {}Expand description
A layer that computes the exponential of all elements in the input tensor, with the base 2.
.. code::
y = Exp2Layer(x)Requires 1 input and produces 1 output. Output shape is same as the input.