FillDynamicLayerParams

Struct FillDynamicLayerParams 

pub struct FillDynamicLayerParams {
    pub value: f32,
}
A layer that generates an output tensor with a constant value. This layer is used to allocate a tensor with a dynamic shape (as specified by the input) and constant value.

Requires 1 input and produces 1 output.

.. code::

  y = FillDynamicLayer(x)

Input A rank 1 tensor specifying the shape of the output

Output An N-Dimensional tensor with the shape specified by the values in the input tensor.

Fields

value: f32