pub struct FillLikeLayerParams {
pub value: f32,
}Expand description
A layer that generates an output tensor with a constant value. Input is only used to determine the shape of the output. This layer is used to allocate a tensor with a dynamic shape (that of the input) and constant value.
Requires 1 input and produces 1 output.
.. code::
y = FillLikeLayer(x)Input A N-Dimensional tensor, whose values are ignored. Only the shape is used to infer the shape of the output.
Output A N-Dimensional tensor with the same shape as the input tensor.
Fields
value: f32Trait Implementations
Sourceimpl Clone for FillLikeLayerParams
impl Clone for FillLikeLayerParams
Sourcefn clone(&self) -> FillLikeLayerParams
fn clone(&self) -> FillLikeLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FillLikeLayerParams
impl Debug for FillLikeLayerParams
Sourceimpl Default for FillLikeLayerParams
impl Default for FillLikeLayerParams
Sourceimpl Message for FillLikeLayerParams
impl Message for FillLikeLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for FillLikeLayerParams
impl PartialEq for FillLikeLayerParams
Sourcefn eq(&self, other: &FillLikeLayerParams) -> bool
fn eq(&self, other: &FillLikeLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for FillLikeLayerParams
impl StructuralPartialEq for FillLikeLayerParams