pub struct FunctionDescription {
pub name: String,
pub input: Vec<FeatureDescription>,
pub output: Vec<FeatureDescription>,
pub state: Vec<FeatureDescription>,
pub predicted_feature_name: String,
pub predicted_probabilities_name: String,
}Expand description
A description of a function.
Fields
name: StringThe function name.
input: Vec<FeatureDescription>Input feature descriptions for the function.
output: Vec<FeatureDescription>Output feature descriptions for the function.
state: Vec<FeatureDescription>State feature descriptions for the function.
The type of each feature description must be StateFeatureType.
predicted_feature_name: String[Required for regressor and classifier functions]: the name to give to an output feature containing the prediction.
predicted_probabilities_name: String[Optional for classifier functions]: the name to give to an output feature containing a dictionary mapping class labels to their predicted probabilities. If not specified, the dictionary will not be returned by the model.