pub struct GlmClassifier {
pub weights: Vec<DoubleArray>,
pub offset: Vec<f64>,
pub post_evaluation_transform: i32,
pub class_encoding: i32,
pub class_labels: Option<ClassLabels>,
}Expand description
A generalized linear model classifier.
Fields
weights: Vec<DoubleArray>offset: Vec<f64>post_evaluation_transform: i32class_encoding: i32class_labels: Option<ClassLabels>Required class label mapping.
Implementations
Sourceimpl GlmClassifier
impl GlmClassifier
Sourcepub fn post_evaluation_transform(&self) -> PostEvaluationTransform
pub fn post_evaluation_transform(&self) -> PostEvaluationTransform
Returns the enum value of post_evaluation_transform, or the default if the field is set to an invalid enum value.
Sourcepub fn set_post_evaluation_transform(&mut self, value: PostEvaluationTransform)
pub fn set_post_evaluation_transform(&mut self, value: PostEvaluationTransform)
Sets post_evaluation_transform to the provided enum value.
Sourcepub fn class_encoding(&self) -> ClassEncoding
pub fn class_encoding(&self) -> ClassEncoding
Returns the enum value of class_encoding, or the default if the field is set to an invalid enum value.
Sourcepub fn set_class_encoding(&mut self, value: ClassEncoding)
pub fn set_class_encoding(&mut self, value: ClassEncoding)
Sets class_encoding to the provided enum value.