Imputer

Struct Imputer 

pub struct Imputer {
    pub imputed_value: Option<ImputedValue>,
    pub replace_value: Option<ReplaceValue>,
}
A transformer that replaces missing values with a default value, such as a statistically-derived value.

If ReplaceValue is set, then missing values of that type are replaced with the corresponding value.

For example: if replaceDoubleValue is set to NaN and a single NaN double value is provided as input, then it is replaced by imputedDoubleValue. However if the input is an array of doubles, then any instances of NaN in the array is replaced with the corresponding value in imputedDoubleArray.

Fields

imputed_value: Option<ImputedValue>replace_value: Option<ReplaceValue>