KNearestNeighborsClassifier

Struct KNearestNeighborsClassifier 

pub struct KNearestNeighborsClassifier {
    pub nearest_neighbors_index: Option<NearestNeighborsIndex>,
    pub number_of_neighbors: Option<Int64Parameter>,
    pub class_labels: Option<ClassLabels>,
    pub default_class_label: Option<DefaultClassLabel>,
    pub weighting_scheme: Option<WeightingScheme>,
}
A k-Nearest-Neighbor classifier

Fields

nearest_neighbors_index: Option<NearestNeighborsIndex>

The “core” nearest neighbor model attributes.

number_of_neighbors: Option<Int64Parameter>

Number of neighbors to use for classification.

class_labels: Option<ClassLabels>

Type of labels supported by the model. Currently supports String or Int64 labels.

default_class_label: Option<DefaultClassLabel>

Default value of class label (useful when prediction is called on an empty kNN classifier)

weighting_scheme: Option<WeightingScheme>

Weighting scheme to be used when computing the majority label of a new data point.