L2NormalizeLayerParams

Struct L2NormalizeLayerParams 

pub struct L2NormalizeLayerParams {
    pub epsilon: f32,
}
A layer that performs L2 normalization, i.e. divides by the the square root of the sum of squares of all elements of input.

.. code::

  y = L2NormalizeLayer(x)

Requires 1 input and produces 1 output.

Input A blob with rank greater than equal to 3. For ranks greater than 3, the leading dimensions, starting from 0 to -4 (inclusive), are all treated as batch. Output A blob with the same shape as the input.

This layer is described by the following formula:

.. math:: x_i \leftarrow \dfrac{x_i}{\sqrt{\sum{x_i^2} + \epsilon}}

Fields

epsilon: f32

A small constant to avoid division by 0 while normalizing variance. Defaults to 1e-6 if not set or set to 0.