pub struct LayerNormalizationLayerParams {
pub normalized_shape: Vec<i64>,
pub eps: f32,
pub gamma: Option<WeightParams>,
pub beta: Option<WeightParams>,
}Expand description
A layer that applies layer normalization over the input tensor.
Requires 1 input and produces 1 output.
output = gamma * (input - computed_mean) / (sqrt(computed_variance + eps)) + beta
Parameters normalizedShape: subset of the input shape, along with layer norm is performed, rest of the input shape is treated as the batch dimension. The mean and variance are computed for the input, over the last few dimensions as specified by the normalizedShape parameter. gamma: must have shape = “normalizedShape” beta: must have shape = “normalizedShape” eps: small constant to avoid division by 0
Output shape is same as the input.
e.g.: input shape = (10,5) normalized shape = (5,) or (10,5)
input shape = (10,5,6,7) normalized shape = (7,) or (6,7) or (5,6,7) or (10,5,6,7)
Fields
normalized_shape: Vec<i64>eps: f32gamma: Option<WeightParams>beta: Option<WeightParams>Trait Implementations
Sourceimpl Clone for LayerNormalizationLayerParams
impl Clone for LayerNormalizationLayerParams
Sourcefn clone(&self) -> LayerNormalizationLayerParams
fn clone(&self) -> LayerNormalizationLayerParams
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Message for LayerNormalizationLayerParams
impl Message for LayerNormalizationLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for LayerNormalizationLayerParams
impl PartialEq for LayerNormalizationLayerParams
Sourcefn eq(&self, other: &LayerNormalizationLayerParams) -> bool
fn eq(&self, other: &LayerNormalizationLayerParams) -> bool
self and other values to be equal, and is used by ==.