pub struct LinearQuantizationParams {
pub scale: Vec<f32>,
pub bias: Vec<f32>,
}Fields
scale: Vec<f32>Stores scale and bias values corresponding to the quantized weights. Must be an array of 1 element, or an array of C elements, where C is number of output channels. For recurrent layers it is equal to the output vector size.
Relationship between quantized weights, unquantized weights, scale and bias:
W_unquantized = W_quantized * scale + bias
bias: Vec<f32>Trait Implementations
Sourceimpl Clone for LinearQuantizationParams
impl Clone for LinearQuantizationParams
Sourcefn clone(&self) -> LinearQuantizationParams
fn clone(&self) -> LinearQuantizationParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinearQuantizationParams
impl Debug for LinearQuantizationParams
Sourceimpl Default for LinearQuantizationParams
impl Default for LinearQuantizationParams
Sourceimpl Message for LinearQuantizationParams
impl Message for LinearQuantizationParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for LinearQuantizationParams
impl PartialEq for LinearQuantizationParams
Sourcefn eq(&self, other: &LinearQuantizationParams) -> bool
fn eq(&self, other: &LinearQuantizationParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LinearQuantizationParams