pub struct LinkedModelFile {
pub linked_model_file_name: Option<StringParameter>,
pub linked_model_search_path: Option<StringParameter>,
}Expand description
Model is referenced by a model file name and search path
Fields
linked_model_file_name: Option<StringParameter>Model file name: e.g. “MyFetureExtractor.mlmodelc”
linked_model_search_path: Option<StringParameter>Search path to find the linked model file Multiple paths can be searched using the unix-style path separator “:” Each path can be relative (to this model) or absolute
An empty string is the same as the relative search path “.” which searches in the same location as this model file
There are some special paths which start with $
- $BUNDLE_MAIN - Indicates to look in the main bundle
- $BUNDLE_IDENTIFIER(identifier) - Looks in Bunde with given identifier