pub struct LogicalNotLayerParams {}Expand description
LogicalNot Layer
Must have 1 input, produces 1 output. Perform elementwise logical NOT operation.
Input is considered False if equal to 0.0f otherwise True. Output is 1.0f if the condition is true otherwise 0.0f.
.. code::
y = NOT(x)Trait Implementations
Sourceimpl Clone for LogicalNotLayerParams
impl Clone for LogicalNotLayerParams
Sourcefn clone(&self) -> LogicalNotLayerParams
fn clone(&self) -> LogicalNotLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogicalNotLayerParams
impl Debug for LogicalNotLayerParams
Sourceimpl Default for LogicalNotLayerParams
impl Default for LogicalNotLayerParams
Sourceimpl Hash for LogicalNotLayerParams
impl Hash for LogicalNotLayerParams
Sourceimpl Message for LogicalNotLayerParams
impl Message for LogicalNotLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for LogicalNotLayerParams
impl PartialEq for LogicalNotLayerParams
Sourcefn eq(&self, other: &LogicalNotLayerParams) -> bool
fn eq(&self, other: &LogicalNotLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for LogicalNotLayerParams
impl Eq for LogicalNotLayerParams
impl StructuralPartialEq for LogicalNotLayerParams