pub struct LoopContinueLayerParams {}Expand description
Loop Continue Layer
Stop the current loop iteration and continue on the next iteration. If present, it should always reside in the “bodyNetwork” of the loop layer
No inputs/outputs