LoopLayerParams

Struct LoopLayerParams 

pub struct LoopLayerParams {
    pub max_loop_iterations: u64,
    pub condition_var: String,
    pub condition_network: Option<NeuralNetwork>,
    pub body_network: Option<NeuralNetwork>,
}
Loop Layer

A layer that provides the functionality of a “for” loop or a “while” loop.

There are either no inputs or 1 input. When an input is present, it corresponds to the maximum loop count, in that case the value of the “maxLoopIterations” field is ignored. Input must be a scalar. (For description below, maxLoopIterations is assumed to be the value of the input, when its present)

No outputs are produced. Blobs produced by the condition or the body network are visible in the scope of the overall network.

“conditionNetwork” must produce a tensor with the name specified in the “conditionVar” field.

There are 3 possible cases for determining the termination condition:

Case 1:

If there is no “conditionNetwork”, in this case the layer corresponds to a pure for loop, which is run “maxLoopIterations” number of times. Equivalent pseudo-code:

for loopIterator = 0 : maxLoopIterations bodyNetwork()

Case 2:

“conditionNetwork” is present, and “maxLoopIterations” is 0 and there is no input, in this case the layer corresponds to a while loop. Equivalent pseudo-code:

conditionVar = conditionNetwork() while conditionVar: bodyNetwork() conditionVar = conditionNetwork()

Case 3:

“conditionNetwork” is provided, and “maxLoopIterations” is positive or there is an input, in this case the layer corresponds to a while loop with a joint condition. Equivalent pseudo-code:

loopIterator = 0 conditionVar = conditionNetwork() while (conditionVar and loopIterator < maxLoopIterations): bodyNetwork() loopIterator = loopIterator + 1 conditionVar = conditionNetwork()

Fields

max_loop_iterations: u64

maximum number of iterations. Ignored if input is present.

condition_var: String

This field provides the name of the tensor which is produced by the conditionNetwork and whose value is checked to start/continue/terminate the loop. Value close to 0.0f is treated as False. This field is optional. Must be a non empty string if and only if “conditionNetwork” is present.

condition_network: Option<NeuralNetwork>

Must generate a tensor with the name provided in the “conditionVar” field. This field is optional. Must be present if and only if “conditionVar” field is a non empty string.

body_network: Option<NeuralNetwork>

Body of the loop. This field must be present.