pub struct LowerTriangularLayerParams {
pub k: i64,
}Expand description
A layer that copies a tensor setting everything outside lower triangular to zero.
Requires 1 input and produces 1 output.
Output shape is same as the input shape. Rank of the input must be at least 2. For rank higher than 2, the last 2 dimensions are treated as the matrix, while the rest are treated as batch.
Fields
k: i64Diagonal above which to zero elements. k = 0 (the default) is the main diagonal, k < 0 is below it and k > 0 is above