pub struct MatrixBandPartLayerParams {
pub num_lower: i64,
pub num_upper: i64,
}Expand description
A layer that copies a tensor setting everything outside a central band in each inner-most matrix to zero.
Requires 1 input and produces 1 output.
Parameters for matrix_band_part layer band(m, n) = (num_lower < 0 || (m-n) <= num_lower) && (num_upper < 0 || (n-m) <= num_upper). output[i, j, k, …, m, n] = band(m, n) * input[i, j, k, …, m, n]
Output shape is same as the input shape. Rank of the input must be at least 2. For rank higher than 2, the last 2 dimensions are treated as the matrix, while the rest are treated as batch.
Fields
num_lower: i64num_upper: i64Trait Implementations
Sourceimpl Clone for MatrixBandPartLayerParams
impl Clone for MatrixBandPartLayerParams
Sourcefn clone(&self) -> MatrixBandPartLayerParams
fn clone(&self) -> MatrixBandPartLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatrixBandPartLayerParams
impl Debug for MatrixBandPartLayerParams
Sourceimpl Default for MatrixBandPartLayerParams
impl Default for MatrixBandPartLayerParams
Sourceimpl Hash for MatrixBandPartLayerParams
impl Hash for MatrixBandPartLayerParams
Sourceimpl Message for MatrixBandPartLayerParams
impl Message for MatrixBandPartLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MatrixBandPartLayerParams
impl PartialEq for MatrixBandPartLayerParams
Sourcefn eq(&self, other: &MatrixBandPartLayerParams) -> bool
fn eq(&self, other: &MatrixBandPartLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for MatrixBandPartLayerParams
impl Eq for MatrixBandPartLayerParams
impl StructuralPartialEq for MatrixBandPartLayerParams