pub struct MaxLayerParams {}Expand description
A layer that computes the elementwise maximum over the inputs.
.. code::
y = MaxLayer(x1,x2,...)Requires multiple inputs and produces 1 output.
Input In general, there are no rank constraints. However, only certain set of shapes are broadcastable. For example: [B, C, 1, 1], [B, C, H, W] Output A blob with the same shape as each input.