pub struct MeanVarianceNormalizeLayerParams {
pub across_channels: bool,
pub normalize_variance: bool,
pub epsilon: f32,
}Expand description
A layer that performs mean variance normalization, along axis = -3.
.. code::
y = MeanVarianceNormalizeLayer(x)Requires 1 input and produces 1 output.
Input A blob with rank greater than equal to 3. Example: Rank 4 blob represents [Batch, channels, height, width] For ranks greater than 3, the leading dimensions, starting from 0 to -4 (inclusive), are all treated as batch.
Output A blob with the same shape as the input.
If acrossChannels == true
normalization is performed on flattened input, i.e. the input is reshaped to (Batch,C), where “Batch” contains
all dimensions from 0 to -4 (inclusive), and C contains dimensions -1, -2, -3.
If acrossChannels == false
normalization is performed within a channel,
across spatial dimensions (i.e. last two dimensions).
Fields
across_channels: boolIf true, mean and variance are computed across channels.
normalize_variance: boolIf false, only mean is subtracted.
epsilon: f32A small constant to avoid division by 0 while normalizing variance.
Defaults to 1e-6 if not set or set to 0.