MultiplyLayerParams

Struct MultiplyLayerParams 

pub struct MultiplyLayerParams {
    pub alpha: f32,
}
A layer that performs elementwise multiplication. This layer has limited broadcasting support. For general broadcasting see MultiplyBroadcastableLayer.

.. code::

  y = MultiplyLayer(x1,x2,...)

Requires 1 or more than 1 input and produces 1 output.

Input In general, there are no rank constraints. However, only certain set of shapes are broadcastable. For example: [B, 1, 1, 1], [B, C, 1, 1], [B, 1, H, W], [B, C, H, W] Output A blob with shape equal to the first input blob.

If only one input is provided, scalar multiplication is performed:

.. math:: y = \alpha x

Fields

alpha: f32

Scalar to be multiplied with the input. Only used if there is a single input.