pub struct NetworkUpdateParameters {
pub loss_layers: Vec<LossLayer>,
pub optimizer: Option<Optimizer>,
pub epochs: Option<Int64Parameter>,
pub shuffle: Option<BoolParameter>,
pub seed: Option<Int64Parameter>,
}Expand description
Details on how the network will be updated
Fields
loss_layers: Vec<LossLayer>optimizer: Option<Optimizer>epochs: Option<Int64Parameter>shuffle: Option<BoolParameter>Describes whether to shuffle the batch of data between epochs.
seed: Option<Int64Parameter>The seed to be used in an associated random number generator.