pub struct NeuralNetworkLayer {
pub name: String,
pub input: Vec<String>,
pub output: Vec<String>,
pub input_tensor: Vec<Tensor>,
pub output_tensor: Vec<Tensor>,
pub is_updatable: bool,
pub layer: Option<Layer>,
}Expand description
A single neural network layer.
Fields
name: Stringdescriptive name of the layer
input: Vec<String>output: Vec<String>input_tensor: Vec<Tensor>must be the same length as the “input” field
output_tensor: Vec<Tensor>must be the same length as the “output” field
is_updatable: boolMust be set to true to mark the layer as updatable. If true, the weightParams in the layer’s properties must also be set to updatable If false, the value of the isUpdatable parameter within the layer’s weights are ignored
layer: Option<Layer>Trait Implementations
Sourceimpl Clone for NeuralNetworkLayer
impl Clone for NeuralNetworkLayer
Sourcefn clone(&self) -> NeuralNetworkLayer
fn clone(&self) -> NeuralNetworkLayer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NeuralNetworkLayer
impl Debug for NeuralNetworkLayer
Sourceimpl Default for NeuralNetworkLayer
impl Default for NeuralNetworkLayer
Sourceimpl Message for NeuralNetworkLayer
impl Message for NeuralNetworkLayer
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NeuralNetworkLayer
impl PartialEq for NeuralNetworkLayer
Sourcefn eq(&self, other: &NeuralNetworkLayer) -> bool
fn eq(&self, other: &NeuralNetworkLayer) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NeuralNetworkLayer