pub struct NeuralNetworkMeanImage {
pub mean_image: Vec<f32>,
}Expand description
A neural network preprocessor that
subtracts the provided mean image from the input image.
The mean image is subtracted from the input named
NeuralNetworkPreprocessing.featureName.
Fields
mean_image: Vec<f32>Mean image stored as a flattened array of floats, representing shape [Channel,Height,Width].