pub struct NeuralNetworkRegressor {
pub layers: Vec<NeuralNetworkLayer>,
pub preprocessing: Vec<NeuralNetworkPreprocessing>,
pub array_input_shape_mapping: i32,
pub image_input_shape_mapping: i32,
pub update_params: Option<NetworkUpdateParameters>,
}Expand description
A neural network specialized as a regressor.
Fields
layers: Vec<NeuralNetworkLayer>preprocessing: Vec<NeuralNetworkPreprocessing>array_input_shape_mapping: i32use this enum value to determine the input tensor shapes to the neural network, for multiarray inputs
image_input_shape_mapping: i32use this enum value to determine the input tensor shapes to the neural network, for image inputs
update_params: Option<NetworkUpdateParameters>Implementations
Sourceimpl NeuralNetworkRegressor
impl NeuralNetworkRegressor
Sourcepub fn array_input_shape_mapping(&self) -> NeuralNetworkMultiArrayShapeMapping
pub fn array_input_shape_mapping(&self) -> NeuralNetworkMultiArrayShapeMapping
Returns the enum value of array_input_shape_mapping, or the default if the field is set to an invalid enum value.
Sourcepub fn set_array_input_shape_mapping(
&mut self,
value: NeuralNetworkMultiArrayShapeMapping,
)
pub fn set_array_input_shape_mapping( &mut self, value: NeuralNetworkMultiArrayShapeMapping, )
Sets array_input_shape_mapping to the provided enum value.
Sourcepub fn image_input_shape_mapping(&self) -> NeuralNetworkImageShapeMapping
pub fn image_input_shape_mapping(&self) -> NeuralNetworkImageShapeMapping
Returns the enum value of image_input_shape_mapping, or the default if the field is set to an invalid enum value.
Sourcepub fn set_image_input_shape_mapping(
&mut self,
value: NeuralNetworkImageShapeMapping,
)
pub fn set_image_input_shape_mapping( &mut self, value: NeuralNetworkImageShapeMapping, )
Sets image_input_shape_mapping to the provided enum value.