pub struct PrecisionRecallCurve {
pub precision_values: Option<FloatVector>,
pub precision_confidence_thresholds: Option<FloatVector>,
pub recall_values: Option<FloatVector>,
pub recall_confidence_thresholds: Option<FloatVector>,
}Expand description
Precision/Recall curve.
The syntax comprises two tables, one to look up the confidence value threshold for a given precision, and the other for a given recall.
Example: –––––––––––+––+––+––+––+––+––+––+––+–– precisionValues | .1 | .2 | .3 | .4 | .5 | .6 | .7 | precisionConfidence | .0 | .0 | .0 | .0 | .1 | .3 | .4 | –––––––––––+––+––+––+––+––+––+––+––+––
–––––––––––+––+––+––+––+––+––+––+––+–– recallValues | .1 | .2 | .3 | .4 | .5 | .6 | .7 | .8 | .9 recallConfidence | .7 | .6 | .5 | .4 | .3 | .3 | .2 | .1 | .0 –––––––––––+––+––+––+––+––+––+––+––+––
The application expects that, when it filters out samples with confidence threshold = 0.1, it gets precision = 0.5. Likewise, with threshold = 0.2 it gets recall = 0.7.
The table must have only valid values; do not use NaN, +/- INF,
or negative values. The application is responsible for inter/extrapolating
approprate confidence threshold based on the application’s specific need.
Fields
precision_values: Option<FloatVector>precision_confidence_thresholds: Option<FloatVector>recall_values: Option<FloatVector>recall_confidence_thresholds: Option<FloatVector>Trait Implementations
Sourceimpl Clone for PrecisionRecallCurve
impl Clone for PrecisionRecallCurve
Sourcefn clone(&self) -> PrecisionRecallCurve
fn clone(&self) -> PrecisionRecallCurve
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PrecisionRecallCurve
impl Debug for PrecisionRecallCurve
Sourceimpl Default for PrecisionRecallCurve
impl Default for PrecisionRecallCurve
Sourceimpl Message for PrecisionRecallCurve
impl Message for PrecisionRecallCurve
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for PrecisionRecallCurve
impl PartialEq for PrecisionRecallCurve
Sourcefn eq(&self, other: &PrecisionRecallCurve) -> bool
fn eq(&self, other: &PrecisionRecallCurve) -> bool
self and other values to be equal, and is used by ==.