RandomBernoulliDynamicLayerParams

Struct RandomBernoulliDynamicLayerParams 

pub struct RandomBernoulliDynamicLayerParams {
    pub seed: i64,
    pub prob: f32,
}
A layer that returns a tensor filled with values from the Bernoulli distribution.

Requires 1 input and produces 1 output.

Parameters: seed: seed used for the Bernoulli distribution. prob: probability of a 1 event.

Input A rank 1 tensor specifying the shape of the output

Output An N-Dimensional tensor with the shape specified by the values in the input tensor.

Fields

seed: i64prob: f32