pub struct RandomUniformDynamicLayerParams {
pub seed: i64,
pub min_val: f32,
pub max_val: f32,
}Expand description
A layer that returns a tensor filled with values from the uniform distribution.
Requires 1 input and produces 1 output.
Parameters: seed: seed used for the uniform distribution. minVal: lower bound on the range of random values for the uniform distribution. maxVal: upper bound on the range of random values for the uniform distribution.
Input A rank 1 tensor specifying the shape of the output
Output An N-Dimensional tensor with the shape specified by the values in the input tensor.
Fields
seed: i64min_val: f32max_val: f32Trait Implementations
Sourceimpl Clone for RandomUniformDynamicLayerParams
impl Clone for RandomUniformDynamicLayerParams
Sourcefn clone(&self) -> RandomUniformDynamicLayerParams
fn clone(&self) -> RandomUniformDynamicLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Message for RandomUniformDynamicLayerParams
impl Message for RandomUniformDynamicLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RandomUniformDynamicLayerParams
impl PartialEq for RandomUniformDynamicLayerParams
Sourcefn eq(&self, other: &RandomUniformDynamicLayerParams) -> bool
fn eq(&self, other: &RandomUniformDynamicLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RandomUniformDynamicLayerParams
impl StructuralPartialEq for RandomUniformDynamicLayerParams