RandomUniformLikeLayerParams

Struct RandomUniformLikeLayerParams 

pub struct RandomUniformLikeLayerParams {
    pub seed: i64,
    pub min_val: f32,
    pub max_val: f32,
}
A layer that returns a tensor filled with values from the uniform distribution.

Requires 1 input and produces 1 output.

Parameters seed: seed used for the uniform distribution. minVal: lower bound on the range of random values for the uniform distribution. maxVal: upper bound on the range of random values for the uniform distribution.

Input An N-Dimensional tensor, whose values are ignored. Only the shape is used to infer the shape of the output.

Output An N-Dimensional tensor with the same shape as the input tensor.

Fields

seed: i64min_val: f32max_val: f32