RangeDynamicLayerParams

Struct RangeDynamicLayerParams 

pub struct RangeDynamicLayerParams {
    pub start_value: f32,
    pub step_size_value: f32,
}
A layer that returns a tensor that contains evenly spaced values. Its functionality is similar to the numpy.arange method.

Requires at least 1 input, up to a maximum of 3 inputs. Produces 1 output, which is a rank 1 tensor.

Each input must be a scalar, or rank 1 and shape (1,).

The first input represents the “endValue”. The second input, if present, corresponds to “startValue”. In this case the value of the “startValue” parameter is ignored. The third input, if present, corresponds to “stepSizeValue”. In this case the value of the “stepSizeValue” parameter is ignored.

Fields

start_value: f32step_size_value: f32