pub struct RangeStaticLayerParams {
pub end_value: f32,
pub start_value: f32,
pub step_size_value: f32,
}Expand description
RangeStatic layer that returns a tensor that contains evenly spaced values. It is similar in functionality to the numpy.arange method.
Requires no input and produces 1 output. Output is a rank 1 tensor.
Fields
end_value: f32start_value: f32step_size_value: f32Trait Implementations
Sourceimpl Clone for RangeStaticLayerParams
impl Clone for RangeStaticLayerParams
Sourcefn clone(&self) -> RangeStaticLayerParams
fn clone(&self) -> RangeStaticLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RangeStaticLayerParams
impl Debug for RangeStaticLayerParams
Sourceimpl Default for RangeStaticLayerParams
impl Default for RangeStaticLayerParams
Sourceimpl Message for RangeStaticLayerParams
impl Message for RangeStaticLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RangeStaticLayerParams
impl PartialEq for RangeStaticLayerParams
Sourcefn eq(&self, other: &RangeStaticLayerParams) -> bool
fn eq(&self, other: &RangeStaticLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RangeStaticLayerParams
impl StructuralPartialEq for RangeStaticLayerParams