ReduceLayerParams

Struct ReduceLayerParams 

pub struct ReduceLayerParams {
    pub mode: i32,
    pub epsilon: f32,
    pub axis: i32,
}
A layer that reduces the input using a specified operation.

.. code::

  y = ReduceLayer(x)

Requires 1 input and produces 1 output.

Input A blob that can, in general, have any rank. However, depending on the value of “axis” , there may be additional rank constraints. Output A blob with the same rank as the input, which has 1s on the dimensions specified in the parameter “axis”

 Values supported for axis are \[-1\], \[-2\], \[-3\], \[-2,-1\], \[-3,-2,-1\]
 and the equivalent positive values (depending on the rank of the input)
 For mode == 'ArgMax', axis must be \[-1\] or \[-2\] or \[-3\].

Fields

mode: i32

Specifies function used to reduce.

epsilon: f32

Used if mode is LOGSUM. Defaults to 1e-6 if not set or is set to 0.

axis: i32

The following mapping is used for interpreting this parameter: CHW = axis [-3, -2, -1], input must have rank at least 3. HW = axis [-2, -1], input must have rank at least 2. C = axis [-3] H = axis [-2] W = axis [-1]

Implementations

Source

impl ReduceLayerParams

pub fn mode(&self) -> ReduceOperation

Returns the enum value of mode, or the default if the field is set to an invalid enum value.

pub fn set_mode(&mut self, value: ReduceOperation)

Sets mode to the provided enum value.

pub fn axis(&self) -> ReduceAxis

Returns the enum value of axis, or the default if the field is set to an invalid enum value.

pub fn set_axis(&mut self, value: ReduceAxis)

Sets axis to the provided enum value.