pub struct ReduceLogSumLayerParams {
pub axes: Vec<i64>,
pub keep_dims: bool,
pub reduce_all: bool,
}Expand description
A layer that performs reduction with logSum operation.
Negative indexing is supported. Requires 1 input and produces 1 output.
Parameters: axes: dimensions along which to perform reduction keepDims: if True, keep the reduced dimensions (value will be 1), otherwise, reduced dimensions are squeezed reduceAll: ignore the “axes” parameter, perform reduction along all axes
Fields
axes: Vec<i64>keep_dims: boolreduce_all: boolTrait Implementations
Sourceimpl Clone for ReduceLogSumLayerParams
impl Clone for ReduceLogSumLayerParams
Sourcefn clone(&self) -> ReduceLogSumLayerParams
fn clone(&self) -> ReduceLogSumLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReduceLogSumLayerParams
impl Debug for ReduceLogSumLayerParams
Sourceimpl Default for ReduceLogSumLayerParams
impl Default for ReduceLogSumLayerParams
Sourceimpl Hash for ReduceLogSumLayerParams
impl Hash for ReduceLogSumLayerParams
Sourceimpl Message for ReduceLogSumLayerParams
impl Message for ReduceLogSumLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ReduceLogSumLayerParams
impl PartialEq for ReduceLogSumLayerParams
Sourcefn eq(&self, other: &ReduceLogSumLayerParams) -> bool
fn eq(&self, other: &ReduceLogSumLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ReduceLogSumLayerParams
impl StructuralPartialEq for ReduceLogSumLayerParams