pub struct ReshapeDynamicLayerParams {}Expand description
A layer that reshapes a tensor.
Requires 2 inputs and produces 1 output.
First input is the one that is reshaped to produce the output. Second input is a rank 1 tensor specifying the shape of the output. Output tensor has shape as specified by the values in the 2nd input tensor.