SamePadding

Struct SamePadding 

pub struct SamePadding {
    pub asymmetry_mode: i32,
}
Specifies the type of padding to be used with Convolution/Deconvolution and pooling layers. After padding, input spatial shape: \[H_in, W_in\], gets modified to the output spatial shape \[H_out, W_out\]. With Convolution or pooling:

.. code::

  H_out = int_division_round_up(H_in,stride\[0\])
  W_out = int_division_round_up(W_in,stride\[1\])

This is achieved by using the following padding amounts:

.. code::

 totalPaddingHeight = max(0,(H_out-1) * stride\[0\] + KernelSize\[0\] - Hin)
 totalPaddingWidth = max(0,(W_out-1) * stride\[1\] + KernelSize\[1\] - Win)

There are two modes of asymmetry: BOTTOM_RIGHT_HEAVY, and TOP_LEFT_HEAVY.

If the mode is BOTTOM_RIGHT_HEAVY:

.. code::

 topPaddingAmount = floor(totalPaddingHeight / 2)
 bottomPaddingAmount = totalPaddingHeight - topPaddingAmount
 leftPaddingAmount = floor(totalPaddingWidth / 2)
 rightPaddingAmount = totalPaddingWidth - leftPaddingAmount

If the mode is TOP_LEFT_HEAVY:

.. code::

 bottomPaddingAmount = floor(totalPaddingHeight / 2)
 topPaddingAmount = totalPaddingHeight - bottomPaddingAmount
 rightPaddingAmount = floor(totalPaddingWidth / 2)
 leftPaddingAmount = totalPaddingWidth - rightPaddingAmount

With Deconvolution:

.. code::

H_out = H_in * stride\[0\]
W_out = W_in * stride\[1\]

Fields

asymmetry_mode: i32

Implementations

Source

impl SamePadding

pub fn asymmetry_mode(&self) -> SamePaddingMode

Returns the enum value of asymmetry_mode, or the default if the field is set to an invalid enum value.

pub fn set_asymmetry_mode(&mut self, value: SamePaddingMode)

Sets asymmetry_mode to the provided enum value.