pub struct ScaleLayerParams {
pub shape_scale: Vec<u64>,
pub scale: Option<WeightParams>,
pub has_bias: bool,
pub shape_bias: Vec<u64>,
pub bias: Option<WeightParams>,
}Expand description
A layer that performs elmentwise multiplication by a scale factor and optionally adds a bias; both the scale and bias are broadcasted to match the input shape.
.. code::
y = ScaleLayer(x)Requires 1 input and produces 1 output.
Input
A blob with rank at least 3.
e.g.: blob with shape \[C, H, W\].
For ranks greater than 3, the leading dimensions, starting from 0 to -4 (inclusive), are all treated as batch.
Output
A blob with the same shape as the input.
Fields
shape_scale: Vec<u64>The shape of the scale.
Must be one of the following:
\[1\], \[C\], \[1, H, W\] or \[C, H, W\].
scale: Option<WeightParams>The scale values.
The size must be equal to the product of the shape dimensions.
Scale values. Size must be equal to the product of dimensions specified in shapeScale.
has_bias: boolIf true, a bias is added after scaling.
shape_bias: Vec<u64>The shape of the bias.
Must be one of the following:
\[1\], \[C\], \[1, H, W\] or \[C, H, W\].
bias: Option<WeightParams>The bias values.
The size must be equal to the product of the shape dimensions.