pub struct SequenceRepeatLayerParams {
pub n_repetitions: u64,
}Expand description
A layer that repeats a sequence or the dimension sitting at axis = -5
.. code::
y = SequenceRepeatLayer(x)Requires 1 input and produces 1 output.
Input
A blob with rank at least 5.
e.g: shape \[Seq, B, C, H, W\]
Output
A blob with the same rank as the input.
e.g.: for input shape \[Seq, B, C, H, W\], output shape is \[nRepetitions * Seq, B, C, H, W\].
Fields
n_repetitions: u64Number of repetitions.
Defaults to 1 if not set or set to 0.