pub struct SerializedModel {
pub identifier: String,
pub model: Vec<u8>,
}Fields
identifier: StringIdentifier whose content describes the model type of the serialized protocol buffer message.
model: Vec<u8>Must be a valid serialized protocol buffer of the above specified type.