SimpleRecurrentLayerParams

Struct SimpleRecurrentLayerParams 

pub struct SimpleRecurrentLayerParams {
    pub input_vector_size: u64,
    pub output_vector_size: u64,
    pub activation: Option<ActivationParams>,
    pub sequence_output: bool,
    pub has_bias_vector: bool,
    pub weight_matrix: Option<WeightParams>,
    pub recursion_matrix: Option<WeightParams>,
    pub bias_vector: Option<WeightParams>,
    pub reverse_input: bool,
}
A simple recurrent layer.

.. code::

  y_t = SimpleRecurrentLayer(x_t, y_{t-1})

Input A blob of rank 5, with shape `[Seq, Batch, inputVectorSize, 1, 1]. This represents a sequence of vectors of size inputVectorSize. Output Same rank as the input. Represents a vector of size outputVectorSize``. It is either the final output or a sequence of outputs at all time steps.

  • Output Shape: \[1, Batch, outputVectorSize, 1, 1\] , if sequenceOutput == false
  • Output Shape: \[Seq, Batch, outputVectorSize, 1, 1\] , if sequenceOutput == true

This layer is described by the following equation:

.. math:: \boldsymbol{y_t} = f(\mathrm{clip}(W \boldsymbol{x_t} +
R \boldsymbol{y_{t-1}} + b))

  • W is a 2-dimensional weight matrix (\[outputVectorSize, inputVectorSize\], row-major)
  • R is a 2-dimensional recursion matrix (\[outputVectorSize, outputVectorSize\], row-major)
  • b is a 1-dimensional bias vector (\[outputVectorSize\])
  • f() is an activation
  • clip() is a function that constrains values between \[-50.0, 50.0\]

Fields

input_vector_size: u64

The size of the input vectors.

output_vector_size: u64

The size of the output vectors.

activation: Option<ActivationParams>

Activations supported are Linear, Sigmoid, Tanh, ReLU, Scaled Tanh (alpha = 1.71, beta = 2/3), Hard sigmoid (alpha = 0.2, beta = 0.5)

The activation function.

sequence_output: bool

If false output is just the result after final state update. If true, output is a sequence, containing outputs at all time steps.

has_bias_vector: bool

If false, no bias is added.

weight_matrix: Option<WeightParams>

Weight matrix W.

recursion_matrix: Option<WeightParams>

Recursion Weight matrix R.

bias_vector: Option<WeightParams>

Bias vector b.

reverse_input: bool

If true, then the node processes the input sequence from right to left