SliceDynamicLayerParams

Struct SliceDynamicLayerParams 

pub struct SliceDynamicLayerParams {
    pub begin_masks: Vec<bool>,
    pub end_ids: Vec<i64>,
    pub end_masks: Vec<bool>,
    pub strides: Vec<i64>,
    pub squeeze_masks: Vec<bool>,
}
A layer that extracts a slice of size (end - begin) / stride from the given input tensor. Support negative indexing and negative strides. See “SliceStaticLayerParams” for the description and an example of the functionality of the layer.

Requires 2 to 7 inputs and produces 1 output. Rank of the output is same as the rank of the first input unless squeezeMask is set.

Value of beginIds, beginMasks, endIds, endMasks, strides can be passed in either as dynamic inputs or as static parameters. Lengths of all the parameters or inputs from 2-6 must equal the rank of the first input.

The 2nd input represents the “beginIds”. The 3rd input, if present, corresponds to “endIds”. In this case the value of the “endIds” parameter is ignored. The 4th input, if present, corresponds to “strides”. In this case the value of the “strides” parameter is ignored. The 5th input, if present, corresponds to “beginMasks”. In this case the value of the “beginMasks” parameter is ignored. The 6th input, if present, corresponds to “endMasks”. In this case the value of the “endMasks” parameter is ignored. The 7th input, if present, corresponds to “squeezeMasks”. In this case the value of the “squeezeMasks” parameter is ignored.

Fields

begin_masks: Vec<bool>end_ids: Vec<i64>end_masks: Vec<bool>strides: Vec<i64>squeeze_masks: Vec<bool>