SlidingWindowsLayerParams

Struct SlidingWindowsLayerParams 

pub struct SlidingWindowsLayerParams {
    pub axis: i64,
    pub window_size: u64,
    pub step: u64,
}
A layer that returns a tensor containing all windows of size windowSize separated by step along the dimension axis.

.. code::

  y = SlidingWindows(x)

Requires 1 input and produces 1 output.

Input An N-Dimensional tensor.

Output An (N+1)-Dimensional tensor.

This operation behaves as following: - if axis = 0 & input is rank 1 (L,). Output shape will be (M, W). - if axis = 1 & input is rank 3 (B1, L, C1). Output shape will be (B1, M, W, C1) - if axis = 2 & input is rank 5 (B1, B2, L, C1, C2) –> (B1 * B2, L, C1 * C2) –> (B1 * B2, M, W, C1 * C2). Output shape will be (B1, B2, M, W, C1, C2) - etc. where - L, C, B refer to input length, feature dimension length & batch size respectively - W is the window size. - M is the number of windows/slices calculated as M = (L - W) / step + 1

Fields

axis: i64window_size: u64step: u64