pub struct SoftmaxLayerParams {}Expand description
Softmax Normalization Layer
A layer that performs softmax normalization. Normalization is applied along axis = -3 or N-3 (where N is the rank of the input) For softmax layer that can operate on any axis, see SoftmaxNDLayer.
.. code::
y = SoftmaxLayer(x)Requires 1 input and produces 1 output.
Input Must be a blob with rank >= 3. Output A blob with the same shape as the input.
This layer is described by the following formula:
.. math:: x_i \leftarrow \dfrac{e^{x_i}}{\sum_i{e^{x_i}}}