pub struct SplitLayerParams {
pub n_outputs: u64,
}Expand description
A layer that uniformly splits across axis = -3 to produce a specified number of outputs. For general split operation along any axis, see SplitNDLayer.
.. code::
(y1,y2,...yN) = SplitLayer(x), where N = nOutputsRequires 1 input and produces multiple outputs.
Input
A blob with rank at least 3.
e.g.: blob with shape \[C, H, W\]
Output
nOutputs blobs each with same rank as the input.
e.g.: For input that is of shape \[C, H, W\], output shapes will be \[C/nOutputs, H, W\]
Fields
n_outputs: u64The number of outputs.