pub struct StackLayerParams {
pub axis: i64,
}Expand description
A layer that stacks the input tensors along the given axis. It is similar in functionality to the numpy.stack method.
Requires at least 2 inputs and produces 1 output. All inputs must have the same shape. Rank of the output is 1 greater than the rank of the inputs.
Negative indexing is supported for the “axis” parameter.
e.g.:
input shape = (2, 4, 2) number of inputs = 5 axis = 3 output shape = (2, 4, 2, 5)
input shape = (2, 4, 2) number of inputs = 5 axis = -2 output shape = (2, 4, 5, 2)
Fields
axis: i64Trait Implementations
Sourceimpl Clone for StackLayerParams
impl Clone for StackLayerParams
Sourcefn clone(&self) -> StackLayerParams
fn clone(&self) -> StackLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StackLayerParams
impl Debug for StackLayerParams
Sourceimpl Default for StackLayerParams
impl Default for StackLayerParams
Sourceimpl Hash for StackLayerParams
impl Hash for StackLayerParams
Sourceimpl Message for StackLayerParams
impl Message for StackLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StackLayerParams
impl PartialEq for StackLayerParams
Sourcefn eq(&self, other: &StackLayerParams) -> bool
fn eq(&self, other: &StackLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for StackLayerParams
impl Eq for StackLayerParams
impl StructuralPartialEq for StackLayerParams