SupportVectorClassifier

Struct SupportVectorClassifier 

pub struct SupportVectorClassifier {
    pub kernel: Option<Kernel>,
    pub number_of_support_vectors_per_class: Vec<i32>,
    pub coefficients: Vec<Coefficients>,
    pub rho: Vec<f64>,
    pub prob_a: Vec<f64>,
    pub prob_b: Vec<f64>,
    pub support_vectors: Option<SupportVectors>,
    pub class_labels: Option<ClassLabels>,
}
A support vector classifier

Fields

kernel: Option<Kernel>number_of_support_vectors_per_class: Vec<i32>

The number of support vectors for each class.

coefficients: Vec<Coefficients>

The coefficients, essentially a two dimensional array of size: (numberOfClasses-1) by (total number of support vectors)

rho: Vec<f64>

Constants for decision function, with K*(K-1) / 2 elements, where K is the number of classes.

prob_a: Vec<f64>

Pairwise probability information for A vs B classifier. Total of K*(K-1)/2 elements where K is the number of classes. These fields are optional, and only required if you want probabilities or multi class predictions.

prob_b: Vec<f64>support_vectors: Option<SupportVectors>

The support vectors, in either sparse or dense format.

class_labels: Option<ClassLabels>

Class label mapping.