UnaryFunctionLayerParams

Struct UnaryFunctionLayerParams 

pub struct UnaryFunctionLayerParams {
    pub type: i32,
    pub alpha: f32,
    pub epsilon: f32,
    pub shift: f32,
    pub scale: f32,
}
A layer that applies a unary function.

.. code::

  y = UnaryFunctionLayer(x)

Requires 1 input and produces 1 output.

Input A blob with no rank constraints. Output A blob with the same shape as the input.

The input is first modified by shifting and scaling:

.. math:: x \leftarrow \text{scale} \cdot x + \text{shift}

Fields

type: i32

The type of unary function.

alpha: f32

A constant used in POWER and THRESHOLD functions.

epsilon: f32

A small constant to avoid division by 0 while normalizing variance. Defaults to 1e-6 if not set or set to 0.

shift: f32

Input is shifted by this amount before the unary function is applied. Defaults to 0.0 if not set.

scale: f32

Input is scaled by this amount before the unary function is applied. Defaults to 1.0 if not set or set to 0.

Implementations

Source

impl UnaryFunctionLayerParams

pub fn type(&self) -> Operation

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: Operation)

Sets type to the provided enum value.