pub struct UpsampleLayerParams {
pub scaling_factor: Vec<u64>,
pub fractional_scaling_factor: Vec<f32>,
pub mode: i32,
pub linear_upsample_mode: i32,
}Expand description
A layer that scales up spatial dimensions. It supports two modes: nearest neighbour (default) and bilinear.
.. code::
y = UpsampleLayer(x)Requires 1 input and produces 1 output.
Input
A blob with rank at least 3.
e.g.: blob with shape \[C, H, W\].
For ranks greater than 3, the leading dimensions, starting from 0 to -4 (inclusive), are all treated as batch.
Output
Same rank as the input.
e.g.: blob with shape \[C, scalingFactor[0\] * H, scalingFactor\[1\] * W]
Fields
scaling_factor: Vec<u64>Scaling Factor. Mutually exclusive with fractionalScalingFactor.
Must be length 2 in order \[H, W\].
If not set, default value \[1, 1\] is used.
fractional_scaling_factor: Vec<f32>Fractional scaling factor. Mutually exclusive with scalingFactor.
Must be length 2 in order \[H, W\].
If not set, default value \[1.0, 1.0\] is used.
mode: i32linear_upsample_mode: i32Implementations
Sourceimpl UpsampleLayerParams
impl UpsampleLayerParams
Sourcepub fn mode(&self) -> InterpolationMode
pub fn mode(&self) -> InterpolationMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: InterpolationMode)
pub fn set_mode(&mut self, value: InterpolationMode)
Sets mode to the provided enum value.
Sourcepub fn linear_upsample_mode(&self) -> LinearUpsampleMode
pub fn linear_upsample_mode(&self) -> LinearUpsampleMode
Returns the enum value of linear_upsample_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_linear_upsample_mode(&mut self, value: LinearUpsampleMode)
pub fn set_linear_upsample_mode(&mut self, value: LinearUpsampleMode)
Sets linear_upsample_mode to the provided enum value.