pub struct ValidPadding {
pub padding_amounts: Option<BorderAmounts>,
}Expand description
Specifies the type of padding to be used with Convolution/Deconvolution and Pooling layers.
After padding, input spatial shape: \[H_in, W_in\], gets modified to the
output spatial shape \[H_out, W_out\].
.. code::
topPaddingAmount == Height startEdgeSize == borderAmounts\[0\].startEdgeSize
bottomPaddingAmount == Height endEdgeSize == borderAmounts\[0\].endEdgeSize
leftPaddingAmount == Width startEdgeSize == borderAmounts\[1\].startEdgeSize
rightPaddingAmount == Width endEdgeSize == borderAmounts\[1\].endEdgeSizeWith Convolution or Pooling:
.. code::
H_out = int_division_round_down((H_in + topPaddingAmount + bottomPaddingAmount - KernelSize\[0\]),stride\[0\]) + 1which is same as:
.. code::
H_out = int_division_round_up((H_in + topPaddingAmount + bottomPaddingAmount - KernelSize\[0\] + 1),stride\[0\])With Deconvolution:
.. code::
H_out = (H_in-1) * stride\[0\] + kernelSize\[0\] - (topPaddingAmount + bottomPaddingAmount)The equivalent expressions hold true for W_out as well.
By default, the values of paddingAmounts are set to 0,
which results in a “true” valid padding.
If non-zero values are provided for paddingAmounts,
“valid” convolution/pooling is performed within the spatially expanded input.
Fields
padding_amounts: Option<BorderAmounts>Trait Implementations
Sourceimpl Clone for ValidPadding
impl Clone for ValidPadding
Sourcefn clone(&self) -> ValidPadding
fn clone(&self) -> ValidPadding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidPadding
impl Debug for ValidPadding
Sourceimpl Default for ValidPadding
impl Default for ValidPadding
Sourceimpl Message for ValidPadding
impl Message for ValidPadding
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ValidPadding
impl PartialEq for ValidPadding
Sourcefn eq(&self, other: &ValidPadding) -> bool
fn eq(&self, other: &ValidPadding) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ValidPadding