WeightParams

Struct WeightParams 

pub struct WeightParams {
    pub float_value: Vec<f32>,
    pub float16_value: Vec<u8>,
    pub raw_value: Vec<u8>,
    pub int8_raw_value: Vec<u8>,
    pub quantization: Option<QuantizationParams>,
    pub is_updatable: bool,
}
Weights for layer parameters. Weights are stored as repeated floating point numbers using row-major ordering and can represent 1-, 2-, 3-, or 4-dimensional data.

Fields

float_value: Vec<f32>

Values specified in single / float / FP32 precision.

float16_value: Vec<u8>

Values in 16-bit half precision floating point.

raw_value: Vec<u8>

Raw value specification for quantized lower precisions.

This field is interpreted as uintN, where N is the number of bits in quantization. E.g. if n=8, the field is interpreted as an array of UINT8. Use this field for quantized parameters unless specifically noted to use int8RawValue.

int8_raw_value: Vec<u8>

Field to be used if int8DynamicQuantize is set in the parent layer. Cannot be set if rawValue is also set. The values in this field are interpreted as INT8.

If this field is set, following conditions must hold true:

  • QuantizationType == LinearQuantizationParams, such that
    • size of the “scale” field is 1 and “bias” field is empty in “LinearQuantizationParams”
quantization: Option<QuantizationParams>

Quantization related parameters.

is_updatable: bool