pub struct TreeNode {
pub tree_id: u64,
pub node_id: u64,
pub node_behavior: i32,
pub branch_feature_index: u64,
pub branch_feature_value: f64,
pub true_child_node_id: u64,
pub false_child_node_id: u64,
pub missing_value_tracks_true_child: bool,
pub evaluation_info: Vec<EvaluationInfo>,
pub relative_hit_rate: f64,
}Fields
tree_id: u64node_id: u64node_behavior: i32The branch mode parameters.
If branch is false, then the parameters in this section must be filled in to determine how the branching functions.
branch_feature_index: u64If the node behavior mode is a branch mode, then these values must be filled in.
branch_feature_value: f64true_child_node_id: u64false_child_node_id: u64missing_value_tracks_true_child: boolevaluation_info: Vec<EvaluationInfo>relative_hit_rate: f64The relative hit rate of a node for optimization purposes.
This value has no effect on the accuracy of the result; it allows the tree to optimize for frequent branches. The value is relative, compared to the hit rates of other branch nodes.
You typically use a proportion of training samples that reached this node or some similar metric to derive this value.
Implementations
Sourceimpl TreeNode
impl TreeNode
Sourcepub fn node_behavior(&self) -> TreeNodeBehavior
pub fn node_behavior(&self) -> TreeNodeBehavior
Returns the enum value of node_behavior, or the default if the field is set to an invalid enum value.
Sourcepub fn set_node_behavior(&mut self, value: TreeNodeBehavior)
pub fn set_node_behavior(&mut self, value: TreeNodeBehavior)
Sets node_behavior to the provided enum value.