#[repr(i32)]pub enum InterpolationMode {
Nn = 0,
Bilinear = 1,
}Expand description
Overall mode for interpolating new elements when upsampling. NN - Nearest Neighbors - simply pick the nearest true value for interpolated values. BILINEAR - Use bilinear interpolation. See LinearUpsamplingMode for behavior.
Variants
Implementations
Sourceimpl InterpolationMode
impl InterpolationMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.