pub struct Function {
pub inputs: Vec<NamedValueType>,
pub opset: String,
pub block_specializations: HashMap<String, Block>,
pub attributes: HashMap<String, Value>,
}Expand description
A program-level function.
Fields
inputs: Vec<NamedValueType>Function inputs are unordered (name, ValueType) pairs. Inputs intended to process images must be rank-4 Float32 tensors. Dimensions are interpreted as NCHW, with N == 1 and C being 1 for grayscale and 3 for RGB. Names must be valid identifiers as described above.
opset: StringThe active block is drawn from this named specialization.
This key must exist in block_specializations.
block_specializations: HashMap<String, Block>Named specializations of this function.
Specialization keys are the name of the opset that the function specialization is written in. They must be valid identifiers as described above.
Outputs from all blocks must match. They define the outputs of the function. Each block inherits the lexical scope from the function.
attributes: HashMap<String, Value>Any other attributes not described by other fields. Keys must be valid identifiers as described above.