pub struct BroadcastToDynamicLayerParams {}Expand description
A layer that broadcasts a tensor to a new shape.
Requires 2 inputs and produces 1 output.
First input is the one that is broadcasted to produce the output. Second input is a rank 1 tensor specifying the shape of the output. Output tensor has shape as specified by the values in the 2nd input tensor.