ConstantPaddingLayerParams

Struct ConstantPaddingLayerParams 

pub struct ConstantPaddingLayerParams {
    pub value: f32,
    pub pad_amounts: Vec<u64>,
    pub pad_to_given_output_size_mode: bool,
}
Constant padding layer. Pad the input array with a constant value, either along a single given axis or along a set of axes.

Requires 1 or 2 inputs and produces 1 output. The amount of padding can be either set as a parameter (“padAmounts”) or provided as a second input.

Output rank is same as the rank of the first input.

when “padToGivenOutputSizeMode” is False:

output_shape[i] = input_shape[i] + padAmounts[2i] + padAmounts[2i+1], i=0,…,rank-1

Examples:

input shape = (20,10) padAmounts = [0,1,4,0] output shape = (21,14)

input shape = (20,10,5) padAmounts = [0,0,3,4,0,9] output shape = (20,17,14)

when “padToGivenOutputSizeMode” is True

output_shape[i] = max(input_shape[i], max(padAmounts[2i] + padAmounts[2i+1])), i=0,…,rank-1

input shape = (20,10) padAmounts = [0,21,14,0] output shape = (21,14)

input shape = (20,10,5) padAmounts = [0,0,17,0,0,14] output shape = (20,17,14)

Fields

value: f32

The value to be used for padding.

pad_amounts: Vec<u64>

Length of this repeated field must be twice the rank of the first input. 2i-th and (2i+1)-th values represent the amount of padding to be applied to the the i-th input dimension, “before” and “after” the input values, respectively.

pad_to_given_output_size_mode: bool

When this is True, positive values in “padAmounts” are equivalent to the output shape. In that case only one of padAmounts[2i] and padAmounts[2i+1] can be non zero, for i=0,..,rank-1.