CustomModel

Struct CustomModel 

pub struct CustomModel {
    pub class_name: String,
    pub parameters: HashMap<String, CustomModelParamValue>,
    pub description: String,
}
A parameterized model whose function is defined in code

Fields

class_name: String

The name of the class (conforming to MLCustomModel) corresponding to this model

parameters: HashMap<String, CustomModelParamValue>description: String

An (optional) description provided by the model creator. This information is displayed when viewing the model, but does not affect the model’s execution on device.