pub struct FlattenLayerParams {
pub mode: i32,
}Expand description
A layer that flattens the input.
.. code::
y = FlattenLayer(x)Requires 1 input and produces 1 output.
Input
A blob with rank greater than equal to 3.
e.g.: Rank 4 blob represents [Batch, C, H, W]
For ranks greater than 3, the leading dimensions, starting from 0 to -4 (inclusive), are all treated as batch.
Output
Same rank as the input, such that last two dimensions are both 1.
e.g.: For rank 4 input, output shape is \[Batch, C * H * W, 1, 1\]
There are two X orders: CHANNEL_FIRST and CHANNEL_LAST.
CHANNEL_FIRST does not require data to be rearranged,
because row major ordering is used by internal storage.
CHANNEL_LAST requires data to be rearranged.
Fields
mode: i32Implementations
Sourceimpl FlattenLayerParams
impl FlattenLayerParams
Sourcepub fn mode(&self) -> FlattenOrder
pub fn mode(&self) -> FlattenOrder
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: FlattenOrder)
pub fn set_mode(&mut self, value: FlattenOrder)
Sets mode to the provided enum value.