pub struct GetShapeLayerParams {}Expand description
A layer that returns the shape of an input tensor.
Requires 1 input and produces 1 output.
Input: a tensor. Output: a vector of length R, where R is the rank of the input tensor Output is always a rank 1 tensor.