LayerNormalizationLayerParams

Struct LayerNormalizationLayerParams 

pub struct LayerNormalizationLayerParams {
    pub normalized_shape: Vec<i64>,
    pub eps: f32,
    pub gamma: Option<WeightParams>,
    pub beta: Option<WeightParams>,
}
A layer that applies layer normalization over the input tensor.

Requires 1 input and produces 1 output.

output = gamma * (input - computed_mean) / (sqrt(computed_variance + eps)) + beta

Parameters normalizedShape: subset of the input shape, along with layer norm is performed, rest of the input shape is treated as the batch dimension. The mean and variance are computed for the input, over the last few dimensions as specified by the normalizedShape parameter. gamma: must have shape = “normalizedShape” beta: must have shape = “normalizedShape” eps: small constant to avoid division by 0

Output shape is same as the input.

e.g.: input shape = (10,5) normalized shape = (5,) or (10,5)

input shape = (10,5,6,7) normalized shape = (7,) or (6,7) or (5,6,7) or (10,5,6,7)

Fields

normalized_shape: Vec<i64>eps: f32gamma: Option<WeightParams>beta: Option<WeightParams>