ModelDescription

Struct ModelDescription 

pub struct ModelDescription {
    pub functions: Vec<FunctionDescription>,
    pub default_function_name: String,
    pub metadata: Option<Metadata>,
    pub input: Vec<FeatureDescription>,
    pub output: Vec<FeatureDescription>,
    pub state: Vec<FeatureDescription>,
    pub predicted_feature_name: String,
    pub predicted_probabilities_name: String,
    pub training_input: Vec<FeatureDescription>,
}
A description of a model, consisting of descriptions of its input and output features. Both regressor and classifier models require the name of the primary predicted output feature (predictedFeatureName). Classifier models can specify the output feature containing probabilities for the predicted classes (predictedProbabilitiesName).

Fields

functions: Vec<FunctionDescription>

Functions in the model.

Some model types (e.g. ML Program) support multiple functions. For example, a large language model might have “prompt” and “extend” functions. Each has a different input and output behavior, but they are in a same model and share resources.

If the model has more than one function, use the multiple function configuration and declare the feature descriptions and associated properties at function level.

If the model type doesn’t support multiple functions or the model has just “main” function, declare the feature descriptions and associated properties at the model level.

Note: feature descriptions and associated properties mentioned above include input, output, state, predictedFeatureName, predictedProbabilitiesName, and trainingInput fields.

default_function_name: String

The default function.

The default function is the one that is automatically used when one doesn’t explicitly specify.

The value must be one of the names in functions message above. If functions is empty, this field must not be present.

metadata: Option<Metadata>

The metadata (e.g. author, licence, etc) of the model.

input: Vec<FeatureDescription>output: Vec<FeatureDescription>state: Vec<FeatureDescription>

State feature descriptions for the function.

The type of each feature description must be StateFeatureType.

predicted_feature_name: String

[Required for regressor and classifier models]: the name to give to an output feature containing the prediction.

predicted_probabilities_name: String

[Optional for classifier models]: the name to give to an output feature containing a dictionary mapping class labels to their predicted probabilities. If not specified, the dictionary will not be returned by the model.

training_input: Vec<FeatureDescription>