pub struct NeuralNetworkImageScaler {
pub channel_scale: f32,
pub blue_bias: f32,
pub green_bias: f32,
pub red_bias: f32,
pub gray_bias: f32,
}Expand description
A neural network preprocessor that performs a scalar multiplication of an image followed by addition of scalar biases to the channels.
Input: X
An image in BGR or RGB format with shape \[3, H, W\]
or in grayscale format with shape \[1, H, W\].
Output: Y
An image with format and shape corresponding to the input.
If the input image is in BGR format:
.. code::
Y\[0, :, :\] = channelScale * X\[0, :, :\] + blueBias
Y\[1, :, :\] = channelScale * X\[1, :, :\] + greenBias
Y\[2, :, :\] = channelScale * X\[2, :, :\] + redBiasIf the input image is in RGB format:
.. code::
Y\[0, :, :\] = channelScale * X\[0, :, :\] + redBias
Y\[1, :, :\] = channelScale * X\[1, :, :\] + greenBias
Y\[2, :, :\] = channelScale * X\[2, :, :\] + blueBiasIf the input image is in grayscale format:
.. code::
Y\[0, :, :\] = channelScale * X\[0, :, :\] + grayBiasFields
channel_scale: f32Scalar to be multiplied.
blue_bias: f32Scalar blue bias to be added.
green_bias: f32Scalar green bias to be added.
red_bias: f32Scalar red bias to be added.
gray_bias: f32Scalar bias to be added for grayscale images.