OneHotEncoder

Struct OneHotEncoder 

pub struct OneHotEncoder {
    pub output_sparse: bool,
    pub handle_unknown: i32,
    pub category_type: Option<CategoryType>,
}
Transforms a categorical feature into an array. The array will be all zeros expect a single entry of one.

Each categorical value will map to an index, this mapping is given by either the stringCategories parameter or the int64Categories parameter.

Fields

output_sparse: bool

Output can be a dictionary with only one entry, instead of an array.

handle_unknown: i32category_type: Option<CategoryType>

Mapping to be used for the encoding. The position of the category in the below vector determines where the single one entry will be in the output.

Implementations

Source

impl OneHotEncoder

pub fn handle_unknown(&self) -> HandleUnknown

Returns the enum value of handle_unknown, or the default if the field is set to an invalid enum value.

pub fn set_handle_unknown(&mut self, value: HandleUnknown)

Sets handle_unknown to the provided enum value.