pub struct RandomBernoulliDynamicLayerParams {
pub seed: i64,
pub prob: f32,
}Expand description
A layer that returns a tensor filled with values from the Bernoulli distribution.
Requires 1 input and produces 1 output.
Parameters: seed: seed used for the Bernoulli distribution. prob: probability of a 1 event.
Input A rank 1 tensor specifying the shape of the output
Output An N-Dimensional tensor with the shape specified by the values in the input tensor.
Fields
seed: i64prob: f32Trait Implementations
Sourceimpl Clone for RandomBernoulliDynamicLayerParams
impl Clone for RandomBernoulliDynamicLayerParams
Sourcefn clone(&self) -> RandomBernoulliDynamicLayerParams
fn clone(&self) -> RandomBernoulliDynamicLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Message for RandomBernoulliDynamicLayerParams
impl Message for RandomBernoulliDynamicLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RandomBernoulliDynamicLayerParams
impl PartialEq for RandomBernoulliDynamicLayerParams
Sourcefn eq(&self, other: &RandomBernoulliDynamicLayerParams) -> bool
fn eq(&self, other: &RandomBernoulliDynamicLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RandomBernoulliDynamicLayerParams
impl StructuralPartialEq for RandomBernoulliDynamicLayerParams