pub struct RandomUniformLikeLayerParams {
pub seed: i64,
pub min_val: f32,
pub max_val: f32,
}Expand description
A layer that returns a tensor filled with values from the uniform distribution.
Requires 1 input and produces 1 output.
Parameters seed: seed used for the uniform distribution. minVal: lower bound on the range of random values for the uniform distribution. maxVal: upper bound on the range of random values for the uniform distribution.
Input An N-Dimensional tensor, whose values are ignored. Only the shape is used to infer the shape of the output.
Output An N-Dimensional tensor with the same shape as the input tensor.
Fields
seed: i64min_val: f32max_val: f32Trait Implementations
Sourceimpl Clone for RandomUniformLikeLayerParams
impl Clone for RandomUniformLikeLayerParams
Sourcefn clone(&self) -> RandomUniformLikeLayerParams
fn clone(&self) -> RandomUniformLikeLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RandomUniformLikeLayerParams
impl Debug for RandomUniformLikeLayerParams
Sourceimpl Message for RandomUniformLikeLayerParams
impl Message for RandomUniformLikeLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RandomUniformLikeLayerParams
impl PartialEq for RandomUniformLikeLayerParams
Sourcefn eq(&self, other: &RandomUniformLikeLayerParams) -> bool
fn eq(&self, other: &RandomUniformLikeLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RandomUniformLikeLayerParams
impl StructuralPartialEq for RandomUniformLikeLayerParams