pub struct RangeDynamicLayerParams {
pub start_value: f32,
pub step_size_value: f32,
}Expand description
A layer that returns a tensor that contains evenly spaced values. Its functionality is similar to the numpy.arange method.
Requires at least 1 input, up to a maximum of 3 inputs. Produces 1 output, which is a rank 1 tensor.
Each input must be a scalar, or rank 1 and shape (1,).
The first input represents the “endValue”. The second input, if present, corresponds to “startValue”. In this case the value of the “startValue” parameter is ignored. The third input, if present, corresponds to “stepSizeValue”. In this case the value of the “stepSizeValue” parameter is ignored.
Fields
start_value: f32step_size_value: f32Trait Implementations
Sourceimpl Clone for RangeDynamicLayerParams
impl Clone for RangeDynamicLayerParams
Sourcefn clone(&self) -> RangeDynamicLayerParams
fn clone(&self) -> RangeDynamicLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RangeDynamicLayerParams
impl Debug for RangeDynamicLayerParams
Sourceimpl Default for RangeDynamicLayerParams
impl Default for RangeDynamicLayerParams
Sourceimpl Message for RangeDynamicLayerParams
impl Message for RangeDynamicLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RangeDynamicLayerParams
impl PartialEq for RangeDynamicLayerParams
Sourcefn eq(&self, other: &RangeDynamicLayerParams) -> bool
fn eq(&self, other: &RangeDynamicLayerParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RangeDynamicLayerParams
impl StructuralPartialEq for RangeDynamicLayerParams