pub struct SamplingMode {
pub sampling_method: i32,
}Expand description
Specifies how grid points are sampled from an interval.
Without the loss of generality, assume the interval to be [0, X-1] from which N points are to be sampled.
Here X may correspond to an input image’s height or width.
All the methods can be expressed in terms of numpy’s linspace function, along with the constraint that grid points have to lie in the interval [0, X-1].
Note: numpy.linspace(start = start, end = end, num = N, endpoint = True) corresponds to sampling
N points uniformly from the interval [start, end], endpoints included.
The methods vary in how the start and end values are computed.
Fields
sampling_method: i32Implementations
Sourceimpl SamplingMode
impl SamplingMode
Sourcepub fn sampling_method(&self) -> Method
pub fn sampling_method(&self) -> Method
Returns the enum value of sampling_method, or the default if the field is set to an invalid enum value.
Sourcepub fn set_sampling_method(&mut self, value: Method)
pub fn set_sampling_method(&mut self, value: Method)
Sets sampling_method to the provided enum value.