pub struct SlidingWindowsLayerParams {
pub axis: i64,
pub window_size: u64,
pub step: u64,
}Expand description
A layer that returns a tensor containing all windows of size windowSize
separated by step along the dimension axis.
.. code::
y = SlidingWindows(x)Requires 1 input and produces 1 output.
Input An N-Dimensional tensor.
Output An (N+1)-Dimensional tensor.
This operation behaves as following: - if axis = 0 & input is rank 1 (L,). Output shape will be (M, W). - if axis = 1 & input is rank 3 (B1, L, C1). Output shape will be (B1, M, W, C1) - if axis = 2 & input is rank 5 (B1, B2, L, C1, C2) –> (B1 * B2, L, C1 * C2) –> (B1 * B2, M, W, C1 * C2). Output shape will be (B1, B2, M, W, C1, C2) - etc. where - L, C, B refer to input length, feature dimension length & batch size respectively - W is the window size. - M is the number of windows/slices calculated as M = (L - W) / step + 1
Fields
axis: i64window_size: u64step: u64Trait Implementations
Sourceimpl Clone for SlidingWindowsLayerParams
impl Clone for SlidingWindowsLayerParams
Sourcefn clone(&self) -> SlidingWindowsLayerParams
fn clone(&self) -> SlidingWindowsLayerParams
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SlidingWindowsLayerParams
impl Debug for SlidingWindowsLayerParams
Sourceimpl Default for SlidingWindowsLayerParams
impl Default for SlidingWindowsLayerParams
Sourceimpl Hash for SlidingWindowsLayerParams
impl Hash for SlidingWindowsLayerParams
Sourceimpl Message for SlidingWindowsLayerParams
impl Message for SlidingWindowsLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for SlidingWindowsLayerParams
impl PartialEq for SlidingWindowsLayerParams
Sourcefn eq(&self, other: &SlidingWindowsLayerParams) -> bool
fn eq(&self, other: &SlidingWindowsLayerParams) -> bool
self and other values to be equal, and is used by ==.