pub struct TileLayerParams {
pub reps: Vec<u64>,
}Expand description
A layer that constructs a tensor by repeating the input tensor multiple number of times.
Requires 1 or 2 inputs and produces 1 output. Output rank is same as the input rank.
If two inputs are provided, second input is used as “reps” and “reps” parameter is ignored.
If only one input is provided, length of the “reps” parameter must be at least 1 and not greater than the rank of the input. If it is less than the input rank, it is made equal to the input rank by prepending 1’s to it.
e.g.:
input shape = (2, 4, 2) reps = (1, 2, 6) output shape = (2, 8, 12)
input shape = (2, 4, 2) reps = (6) reps after prepending ones = (1, 1, 6) output shape = (2, 4, 12)
input shape = (2, 4, 2) second input = [1, 2, 6] -> shape: (3,) reps = N/A [Ignored] output shape = (2, 8, 12)
Fields
reps: Vec<u64>Trait Implementations
Sourceimpl Clone for TileLayerParams
impl Clone for TileLayerParams
Sourcefn clone(&self) -> TileLayerParams
fn clone(&self) -> TileLayerParams
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TileLayerParams
impl Debug for TileLayerParams
Sourceimpl Default for TileLayerParams
impl Default for TileLayerParams
Sourceimpl Hash for TileLayerParams
impl Hash for TileLayerParams
Sourceimpl Message for TileLayerParams
impl Message for TileLayerParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for TileLayerParams
impl PartialEq for TileLayerParams
Sourcefn eq(&self, other: &TileLayerParams) -> bool
fn eq(&self, other: &TileLayerParams) -> bool
self and other values to be equal, and is used by ==.