pub struct TreeEnsembleParameters {
pub nodes: Vec<TreeNode>,
pub num_prediction_dimensions: u64,
pub base_prediction_value: Vec<f64>,
}Expand description
Tree ensemble parameters.
Fields
nodes: Vec<TreeNode>num_prediction_dimensions: u64The number of prediction dimensions or classes in the model.
All instances of evaluationIndex in a leaf node
must be less than this value,
and the number of values in the basePredictionValue field
must be equal to this value.
For regression, this is the dimension of the prediction. For classification, this is the number of classes.
base_prediction_value: Vec<f64>The base prediction value.
The number of values in this must match the default values of the tree model.